@@ -20,6 +20,7 @@
 STABLE
 """
 
+import six
 import logging
 import time
 from datetime import datetime
@@ -58,7 +59,7 @@ def _get_data_store():
 
 def __datastore_created_cb(object_id):
     metadata = _get_data_store().get_properties(object_id, byte_arrays=True)
-    updated.send(None, object_id=object_id, metadata=metadata)
+    created.send(None, object_id=object_id, metadata=metadata)
 
 
 def __datastore_updated_cb(object_id):
@@ -69,6 +70,7 @@ def __datastore_updated_cb(object_id):
 def __datastore_deleted_cb(object_id):
     deleted.send(None, object_id=object_id)
 
+
 created = dispatch.Signal()
 deleted = dispatch.Signal()
 updated = dispatch.Signal()
@@ -85,6 +87,12 @@ class DSMetadata(GObject.GObject):
         if not properties:
             self._properties = {}
         else:
+            if six.PY3:
+                for x, y in properties.items():
+                    try:
+                        properties[x] = y.decode()
+                    except BaseException:
+                        pass
             self._properties = properties
 
         default_keys = ['activity', 'activity_id',
@@ -97,6 +105,11 @@ class DSMetadata(GObject.GObject):
         return self._properties[key]
 
     def __setitem__(self, key, value):
+        if six.PY3:
+            try:
+                value = value.decode()
+            except BaseException:
+                pass
         if key not in self._properties or self._properties[key] != value:
             self._properties[key] = value
             self.emit('updated')
@@ -112,7 +125,7 @@ class DSMetadata(GObject.GObject):
         return key in self._properties
 
     def keys(self):
-        return self._properties.keys()
+        return list(self._properties.keys())
 
     def get_dictionary(self):
         return self._properties
@@ -128,7 +141,7 @@ class DSMetadata(GObject.GObject):
 
     def update(self, properties):
         """Update all of the metadata"""
-        for (key, value) in properties.items():
+        for (key, value) in list(properties.items()):
             self[key] = value
 
 
@@ -470,6 +483,9 @@ def copy(ds_object, mount_point):
     ds_object -- DSObject to copy
     mount_point -- mount point of the new datastore entry
 
+    Returns:
+    new_ds_object -- DSObject copied
+
     """
     new_ds_object = ds_object.copy()
     new_ds_object.metadata['mountpoint'] = mount_point
@@ -490,6 +506,8 @@ def copy(ds_object, mount_point):
 
     write(new_ds_object)
 
+    return new_ds_object
+
 
 def get_unique_values(key):
     """Retrieve an array of unique values for a field.
